package com.techbooks;

import java.io.FileInputStream;
import java.io.InputStream;
import java.io.IOException;
import java.io.PrintWriter;
import java.net.URL;
import java.util.Iterator;
import java.util.List;
import javax.servlet.*;
import javax.servlet.http.*;

// JDOM
import org.jdom.Document;
import org.jdom.Element;
import org.jdom.JDOMException;
import org.jdom.input.SAXBuilder;

public class GetRSSChannelServlet extends HttpServlet {

    /** Host to connect to for books list */
    private static final String hostname = "newInstance.com";
    /** Port number to connect to for books list */
    private static final int portNumber = 80;
    /** File to request (URI path) for books list */
    private static final String file = "/cgi/supplyBooks.pl";

    public void service(HttpServletRequest req, HttpServletResponse res) 
        throws ServletException, IOException {            
            
        res.setContentType("text/plain");
        PrintWriter out = res.getWriter();
        
        // Connect and get XML listing of books
        URL getBooksURL = new URL("http", hostname, portNumber, file);
        InputStream in = getBooksURL.openStream();

        try {
            // Request SAX Implementation and use default parser
            SAXBuilder builder = new SAXBuilder();

            // Create the document
            Document doc = builder.build(in);
            
            // Output XML
            out.println(generateRSSContent(doc));
            
        } catch (JDOMException e) {        
            out.println("Error: " + e.getMessage());
        } finally {
            out.close();
        }
    }   
    
    /**
     * <p>
     * This will generate an RSS XML document using the supplied 
     *   JDOM <code>Document</code>.
     * </p.
     *
     * @param doc <code>Document</code> to use for input.
     * @return <code>String</code> - RSS file to output.
     * @throws <code>JDOMException</code> when errors occur.
     */
    private String generateRSSContent(Document doc) throws JDOMException {
        StringBuffer rss = new StringBuffer();
        
        rss.append("<?xml version=\"1.0\"?>\n")
           .append("<!DOCTYPE rss PUBLIC ")
           .append("\"-//Netscape Communications//DTD RSS 0.91//EN\" ")
           .append("\"http://my.netscape.com/publish/formats")
           .append("/rss-0.91.dtd\">\n")
           .append("<rss version=\"0.91\">\n")
           .append(" <channel>\n")
           .append("  <title>Technical Books</title>\n")
           .append("  <link>")
           .append("http://newInstance.com/javaxml/techbooks</link>\n")
           .append("  <description>\n")
           .append("   Your online source for technical materials, ")
           .append("computers, and computing books!\n")
           .append("  </description>\n")
           .append("  <language>en-us</language>\n")
           .append("  <image>\n")
           .append("   <title>mytechBooks.com</title>\n")
           .append("   <url>")
           .append("http://newInstance.com/javaxml/techbooks/")
           .append("images/techbooksLogo.gif")
           .append("</url>\n")
           .append("   <link>")
           .append("http://newInstance.com/javaxml/techbooks</link>\n")
           .append("   <width>140</width>\n")
           .append("   <height>23</height>\n")
           .append("   <description>\n")
           .append("    Your source on the Web for technical books.\n")
           .append("   </description>\n")
           .append("  </image>\n");
           
        // Add an item for each new title with Computers as subject
        List books = doc.getRootElement().getChildren("book");
        for (Iterator i = books.iterator(); i.hasNext(); ) {
            Element book = (Element)i.next();
            if (book.getAttribute("subject")
                    .getValue().equals("Computers")) {
                        
                // Output an item
                rss.append("<item>\n")
                    // Add title
                   .append(" <title>")
                   .append(book.getChild("title").getText())
                   .append("</title>\n")
                    // Add link to buy book
                   .append(" <link>")
                   .append("http://newInstance.com/javaxml")
                   .append("/techbooks/buy.xsp?isbn=")
                   .append(book.getChild("saleDetails")
                               .getChild("isbn")
                               .getText())
                   .append("</link>\n")
                   .append(" <description>")
                    // Add description
                   .append(book.getChild("description").getText())
                   .append("</description>\n")                       
                   .append("</item>\n");
                        
            }
        }          
         
        rss.append(" </channel>\n")
           .append("</rss>");
        
        return rss.toString();
    }

}